@@ -437,6 +437,20 @@ ldns_rr_list *ldns_pkt_authority(const ldns_pkt *p);
  * \return the section
  */
 ldns_rr_list *ldns_pkt_additional(const ldns_pkt *p);
+/**
+ * Return the packet's question, answer, authority and additional sections
+ * concatenated, in a new rr_list clone.
+ * \param[in] p the packet
+ * \return the rrs
+ */
+ldns_rr_list *ldns_pkt_all(const ldns_pkt *p);
+/**
+ * Return the packet's answer, authority and additional sections concatenated, 
+ * in a new rr_list clone.  Like ldns_pkt_all but without the questions.
+ * \param[in] p the packet
+ * \return the rrs except the question rrs
+ */
+ldns_rr_list *ldns_pkt_all_noquestion(const ldns_pkt *p);
 
 /**
  * return all the rr_list's in the packet. Clone the lists, instead
@@ -445,7 +459,7 @@ ldns_rr_list *ldns_pkt_additional(const ldns_pkt *p);
  * \param[in] s what section(s) to return
  * \return ldns_rr_list with the rr's or NULL if none were found
  */
-ldns_rr_list *ldns_pkt_get_section_clone(ldns_pkt *p, ldns_pkt_section s);
+ldns_rr_list *ldns_pkt_get_section_clone(const ldns_pkt *p, ldns_pkt_section s);
 
 /**
  * return all the rr with a specific name from a packet. Optionally
@@ -464,7 +478,7 @@ ldns_rr_list *ldns_pkt_rr_list_by_name(ldns_pkt *p, ldns_rdf *r, ldns_pkt_sectio
  * \param[in] s the packet's section
  * \return a list with the rr's or NULL if none were found
  */
-ldns_rr_list *ldns_pkt_rr_list_by_type(ldns_pkt *p, ldns_rr_type t, ldns_pkt_section s);
+ldns_rr_list *ldns_pkt_rr_list_by_type(const ldns_pkt *p, ldns_rr_type t, ldns_pkt_section s);
 /**
  * return all the rr with a specific type and type from a packet. Optionally
  * specify from which section in the packet
@@ -474,7 +488,7 @@ ldns_rr_list *ldns_pkt_rr_list_by_type(ldns_pkt *p, ldns_rr_type t, ldns_pkt_sec
  * \param[in] sec the packet's section
  * \return a list with the rr's or NULL if none were found
  */
-ldns_rr_list *ldns_pkt_rr_list_by_name_and_type(ldns_pkt *packet, ldns_rdf *ownername, ldns_rr_type type, ldns_pkt_section sec);
+ldns_rr_list *ldns_pkt_rr_list_by_name_and_type(const ldns_pkt *packet, const ldns_rdf *ownername, ldns_rr_type type, ldns_pkt_section sec);
 
 
 /**
@@ -826,7 +840,7 @@ bool ldns_pkt_safe_push_rr_list(ldns_pkt *pkt, ldns_pkt_section sec, ldns_rr_lis
 /**
  * check if a packet is empty
  * \param[in] p packet
- * \return true: empty, false: empty
+ * \return true: empty, false: not empty
  */
 bool ldns_pkt_empty(ldns_pkt *p);
 
